;; Generated package description from adoc-mode.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "adoc-mode" "0.8.0.0.20260529.20" "a major-mode for editing AsciiDoc files" '((emacs "28.1")) :commit "4a5e7bfda94c2d5d4b284956bd997880b18a68b8" :authors '(("Florian Kaufmann" . "sensorflo@gmail.com")) :maintainer '("Bozhidar Batsov" . "bozhidar@batsov.dev") :keywords '("asciidoc" "text") :url "https://github.com/bbatsov/adoc-mode")
